@@ -5,7 +5,7 @@ Created on Sat Aug 31 21:21:31 2019
 
 @author: mostafamousavi
 
-last update: 04-03-2020 
+last update: 07-16-2020 
 """
 import json
 import time
@@ -80,9 +80,10 @@ def makeStationList(client_list, min_lat, max_lat, min_lon, max_lon, start_time,
              if net not in filter_network:
                  for st in ev:
                      station = st.code
-                     print(str(net)+"--"+str(station))
     
                      if station not in filter_station:
+                         print(str(net)+"--"+str(station))
+
                          elv = st.elevation
                          lat = st.latitude
                          lon = st.longitude
@@ -110,7 +111,8 @@ def makeStationList(client_list, min_lat, max_lat, min_lon, max_lon, start_time,
     #                                      new_chan2.append(chg)
     #                              new_chan = new_chan2 
     # ============================================================================= 
-                         if len(new_chan) > 0 and (station not in station_list):
+                        
+                         if station not in station_list:
                              station_list[str(station)] ={"network": net,
                                                       "channels": list(set(new_chan)),
                                                       "coords": [lat, lon, elv]
